@@ -100,7 +100,7 @@ def load_phm(return_x_y = False):
     # with open(fdescr_name, encoding='utf8') as f:
         # descr_text = f.read()
 
-    data_file_name = join(module_path, 'data/phm', 'phm_RIGHT_RPhase_FB.csv')
+    data_file_name = join(module_path, 'dataset/data/', 'phm_RIGHT_RPhase_FB.csv')
     dataset = pd.read_csv(data_file_name, header=0, delimiter=',')
     dataset_value = dataset.values
     all_feature_name = dataset.columns.values
@@ -113,10 +113,10 @@ def load_phm(return_x_y = False):
     if return_x_y:
         return x, y
     else:
-        img_file_name = join(module_path, 'visualize_data', 'phm_RIGHT_RPhase_FB.png')
-        plt.figure(figsize=(12, 9))
-        img = mpimg.imread(img_file_name)
-        imgplot = plt.imshow(img)
+        # img_file_name = join(module_path, 'visualize_data', 'phm_RIGHT_RPhase_FB.png')
+        # plt.figure(figsize=(12, 9))
+        # img = mpimg.imread(img_file_name)
+        # imgplot = plt.imshow(img)
         output_data = {'x': x, 'y': y, 'n_feature': n_feature, 'n_sample': n_sample, 'feature_name': feature_name, 'description': descr_text}
         return output_data
 
